@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_100:alloc.c,v 1.8 1997/01/18 20:42:04 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_101:alloc.c,v 1.9 1997/12/16 22:11:41 woods Exp"
  */
 
 /*
@@ -34,6 +34,9 @@
 #include <sys/types.h>
 #include <stdio.h>
 #include "defs.h"
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
 #include "smail.h"
 #include "exitcodes.h"
 #include "log.h"
@@ -56,9 +59,12 @@ static struct block *def_block = &default_block;
 /* variable exported for the X_CHECK macro */
 int x_dont_panic = TRUE;              /* if TRUE, X_CHECK won't call panic */
 
+/* functions imported by this file */
+#if !defined(HAVE_STDLIB_H) && !defined(HAVE_MALLOC_H)
 extern char *malloc();
 extern char *realloc();
 extern void free();				/* int on SunOS */
+#endif
 
 
 /*
