@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_100:default.c,v 1.43 1997/12/08 00:48:46 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_101:default.c,v 1.45 1997/12/16 22:13:38 woods Exp"
  */
 
 /*
@@ -794,7 +794,7 @@ static struct router rewrite_router = {
     "rewrite",				/* routing through rewriter */
     "rewrite",				/* use the rewrite driver */
     SUCC,				/* point to next router */
-    USE_ALWAYS |
+    USE_ALWAYS |			/* we generally want to force rewrite on a match */
 #ifdef REWRITE_OPTIONAL
 	PA_OPTIONAL |			/* the rewrite file is optional */
 #endif
@@ -968,7 +968,8 @@ static struct transport local_transport = {
     SUCC,				/* point to next transport */
     /* put Received:, Return-Path: and From_ line, will do local delivery */
     PUT_RECEIVED | PUT_RETURNPATH | LOCAL_TPORT | LOCAL_XFORM | PUT_FROM |
-	APPEND_AS_USER |
+	APPEND_AS_USER |		/* use uid/gid from addr structure */
+	APPEND_CHECK_USER |		/* make sure $user is safe (no /) */
 #if (!defined(UNIX_SCO) || defined(NO_MMDF_MAILBOXES)) && !defined(MMDF_MAILBOXES)
 	UNIX_FROM_HACK |
 #endif
