@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_100:direct.c,v 1.20 1997/12/02 00:07:37 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_101:direct.c,v 1.22 1997/12/14 05:12:32 woods Exp"
  */
 
 /*
@@ -162,37 +162,40 @@ direct_local_addrs(in, out, retry, defer, fail)
 	    /* initialize list of new addrs found in this pass */
 	    newaddrs = NULL;
 
-            /* If a domain list exists, remove from the input list all those
-            addresses that are not for the domains handled by this
-            director. Afterwards, put them back on the input list. */
-
+	    /* If a domain list exists, remove from the input list all those
+	     * addresses that are not for the domains handled by this
+	     * director.  Afterwards, put them back on the input list.
+	     */
             other_domains = NULL;
-            if (dp->domains) {
-                struct addr *temp = in;
-                struct addr **prev = &in;
+	    if (dp->domains) {
+		struct addr *temp = in;
+		struct addr **prev = &in;
 
-                while (temp != NULL) {
-                    if (!temp->local_name ||
-                      !is_string_in_list(temp->local_name, dp->domains)) {
-                        *prev = temp->succ;
-                        temp->succ = other_domains;
-                        other_domains = temp;
-                        temp = *prev;
-                    } else {
-                        prev = &(temp->succ);
-                        temp = temp->succ;
-                    }
-                }
-            }
+		while (temp != NULL) {
+		    if (!temp->local_name || !is_string_in_list(temp->local_name, dp->domains)) {
+			*prev = temp->succ;
+			temp->succ = other_domains;
+			other_domains = temp;
+			temp = *prev;
+		    } else {
+			prev = &(temp->succ);
+			temp = temp->succ;
+		    }
+		}
+	    }
 
-            /* call the driver if any left */
-            if (in != NULL)
-              in = (*driver->driver)(dp, in, out, &newaddrs, defer, fail);
+	    /* call the driver if any left */
+	    if (in != NULL) {
+		in = (*driver->driver)(dp, in, out, &newaddrs, defer, fail);
+	    }
 
-            /* put back any that were held back */
-            if (other_domains != NULL) {
-                if (in == NULL) in = other_domains; else
-                   insert_addr_list(other_domains, &in, (struct error *) NULL);
+	    /* put back any that were held back */
+	    if (other_domains != NULL) {
+		if (in == NULL) {
+		    in = other_domains;
+		} else {
+		    insert_addr_list(other_domains, &in, (struct error *) NULL);
+		}
             }
 
 	    /* step through newaddrs to verify them */
@@ -611,7 +614,7 @@ finish_direct_other_form(dp, addr)
     default:
 	if (islocalhost(temp_target) &&
 	    EQIC(temp_remainder, addr->parent->remainder) &&
-	    EQIC(temp_target, addr->parent->target))
+	    addr->parent->target && EQIC(temp_target, addr->parent->target))
 	{
 	    /*
 	     * new addr same as input addr, send to
@@ -624,14 +627,16 @@ finish_direct_other_form(dp, addr)
 		   addr->parent->target ? addr->parent->target : "(no-parent-target)",
 		   addr->work_addr,
 		   temp_remainder);
-	    (void) strcpy(addr->work_addr, temp_remainder);
+	    (void) strcpy(addr->work_addr, temp_remainder); /* XXXXXX does this clobber???? */
 	    addr->remainder = addr->work_addr;
 	    xfree(temp_work_addr);
 
 	    return SEND_TO_NEXT;
 	}
-	/* This prevents accidental matching of remainder */
+#if 0 /* since we no longer reparse mailbox forms of localhosts right down to the remainder */
+	/* This prevents accidental matching of remainder for virtual hosts */
 	addr->flags |= ADDR_DONTHASH;
+#endif
 	DEBUG6(DBG_DIRECT_HI,
 	       "    NOT passing %s@%s to next director as %s%s%s%s\n",
 	       addr->parent->remainder,
@@ -1186,7 +1191,6 @@ director_driv_function(struct_p, driver_attrs)
     struct director *dp = (struct director *)struct_p;
     struct direct_driver *drv;
 
-    DEBUG(DBG_ROUTE_HI, "director_driv_function called\n");
     if (dp->driver == NULL) {
 	return xprintf("director %s: no driver attribute", dp->name);
     }
