@@ -1,4 +1,4 @@
-/* @(#) $Id: error.h,v 1.10 1994/10/24 12:34:55 nm4 Exp $ */
+/* @(#) error.h,v 1.15 1996/05/29 18:48:23 woods Exp */
 
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
@@ -93,6 +93,10 @@
 #define ERR_176         176L            /* greybook hosts file lookup error */
 #define ERR_177         177L            /* BIND - CNAME loop */
 #define ERR_178		178L		/* host not found in the DNS */
-#define ERR_1000	1000L		/* bad entry in reroute database */
-#define ERR_1001	1001L		/* failed to open reroute database */
-#define ERR_1002	1002L		/* reroute file lookup error */
+#define ERR_179		179L		/* Malformed user part in remote address */
+#define ERR_180		180L		/* BIND/DNS resolver initialisation failed */
+#define ERR_181		181L		/* bad entry in reroute database */
+#define ERR_182		182L		/* failed to open reroute database */
+#define ERR_183		183L		/* reroute file lookup error */
+#define ERR_184		184L		/* resolve timeout - too long in directors/routers */
+#define ERR_185		185L		/* altuser passwd file is unparsable */
