@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_100:extern.h,v 1.60 1997/10/18 20:30:22 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_101:extern.h,v 1.61 1997/12/16 22:11:44 woods Exp"
  */
 
 /*
@@ -345,7 +345,7 @@ extern void close_database();
 extern int lookup_database();
 
 /* external functions defined in main.c */
-extern void main();
+extern int main();
 extern void initialize_state();
 extern void process_args();
 
