@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_100:hash.c,v 1.8 1997/03/07 03:36:18 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_101:hash.c,v 1.9 1997/12/12 22:07:03 woods Exp"
  */
 
 /*
@@ -585,7 +585,7 @@ add_to_hash(keystr, data, datalen, table)
 	/* 
 	 * if we found the entry, stop
 	 */
-	DEBUG2(DBG_HASH_VHI, "add_to_hash: comparing <%s> to <%s>",
+	DEBUG2(DBG_HASH_VHI, "add_to_hash: comparing <%s> to <%s>\n",
 	       keystr, cur->keystr);
 	if ((cmp = stringcmp(keystr, cur->keystr, caseflag)) == 0) {
 	    DEBUG(DBG_HASH_MID, "add_to_hash: already hashed\n");
