@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_100:log.c,v 1.21 1997/05/23 17:50:58 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_101:log.c,v 1.22 1997/12/16 22:11:46 woods Exp"
  */
 
 /*
@@ -33,6 +33,9 @@
 #else
 # include <varargs.h>
 #endif
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
 #if defined(POSIX_OS)
 # include <unistd.h>
 #else /* not POSIX_OS */
