@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_100:main.h,v 1.6 1996/02/26 18:07:42 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_101:main.h,v 1.7 1997/12/16 22:11:51 woods Exp"
  */
 
 /*
@@ -19,7 +19,7 @@
 #define MAIN_H
 
 /* functions defined in main.c */
-void main();
+extern int main();
 
 /* macros used in main.c */
 
