@@ -1,6 +1,6 @@
 #! /bin/sh
 :
-#ident	"@(#)smail/src:RELEASE-3_2_0_100:mkdrivtab.sh,v 1.13 1997/02/27 16:08:00 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_101:mkdrivtab.sh,v 1.14 1997/12/16 22:25:22 woods Exp"
 
 # Script to create drivertab.c and the driver makefile directories
 # from a driver configuration file.  This script makes heavy use of
@@ -113,7 +113,7 @@ sed -e 's/#.*//' -e '/^[ 	]*$/d' |
     (
 	if [ -f drivertab.c ]; then
 		echo "Build drivertab.c, backup in .drivertab.c" 1>&2
-		mv drivertab.c .drivertab.c
+		mv -f drivertab.c .drivertab.c
 	else
 		echo "Build drivertab.c ..." 1>&2
 	fi
@@ -146,7 +146,7 @@ EOF
 			outfile=$b/Makefile
 			if [ -f $outfile ]; then
 			    echo "Build $outfile, backup in .Makefile" 1>&2
-			    mv $outfile $b/.Makefile
+			    mv -f $outfile $b/.Makefile
 			else
 			    echo "Build $outfile ..." 1>&2
 			fi
