@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_100:modes.c,v 1.71 1997/12/04 01:32:30 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_101:modes.c,v 1.73 1997/12/16 22:11:53 woods Exp"
  */
 
 /*
@@ -1831,7 +1831,7 @@ void
 print_queue()
 {
     char **work;			/* vector of jobs to process */
-    int col;				/* current print column */
+    int col = 0;			/* current print column */
 
     X_PANIC_OKAY();
 
@@ -1845,15 +1845,12 @@ print_queue()
 	char *error;
 
 	/* open without locking */
-	if (open_spool(*work, FALSE, &error) == FAIL) {
-	    if (errfile) {
-		if (errno == 0) {
-		    write_log(LOG_TTY, "%s/%s: %s",
-			      spool_dir, input_spool_fn, error);
-		} else {
-		    write_log(LOG_TTY, "%s/%s: %s: %s",
-			      spool_dir, input_spool_fn, error, strerror(errno));
-		}
+	if (open_spool(*work, FALSE, LOG_TTY) == FAIL) {
+	    if (exitvalue == EX_TEMPFAIL || exitvalue == EX_NOINPUT) {
+		write_log(LOG_TTY|LOG_SYS,
+			  "print_queue: %s/%s: lock failed (this can't happen -- we didn't ask to lock): %s",
+			  spool_dir, input_spool_fn,
+			  exitvalue == EX_TEMPFAIL ? "locked" : "not found");
 	    }
 	    work++;
 	    continue;
@@ -1897,6 +1894,7 @@ print_queue()
 	    }
 	}
 	putchar('\n');
+	/* XXX if we saw a '-t' we should process the header too */
 	if (debug > 0) {
 	    send_log(stdout, TRUE, "Log of transactions:\n");
 	}
@@ -2081,26 +2079,15 @@ int
 process_spool_file(spfn)
     char *spfn;				/* spool file name */
 {
-/* jgt10 - add fstat of file before fork.  If the file isn't there, don't */
-#if 0
-    int pid = fork_wait(); 
-    char *error;
-#endif
     int pid;
-    char *error;
     struct stat statbuf;
 
     /*
-     * Get statistics on spool file.
+     * Verify the spool file exists before we try to process it
      */
-    (void) stat(spfn, &statbuf);
-
-    /*
-     * If the file has been removed, then don't spawn child to process
-     */
-    if (statbuf.st_nlink == 0) {
-	write_log(LOG_SYS, "process_spool_file: %s: File already processed\n",
-		  spfn);
+    if (stat(spfn, &statbuf) < 0) {
+	write_log(LOG_SYS, "process_spool_file: %s: File possibly already processed: %s",
+		  spfn, strerror(errno));
 	return FAIL;
     }
 
@@ -2128,19 +2115,16 @@ process_spool_file(spfn)
 	initialize_state();
 
 	/* in child process, open the message and attempt delivery */
-	if (open_spool(spfn, TRUE, &error) == FAIL) {
-	    if (errno == EAGAIN) {	/* XXX || EACCES, though really should be only ignored in locking  */
-		DEBUG4(DBG_MAIN_LO, "open_spool: %s/%s: %s: %s.\n",
-		       spool_dir, input_spool_fn, error, strerror(errno));
-		exit(EX_TEMPFAIL);
-	    } else if (errno == 0) {
-		write_log(LOG_SYS, "open_spool: %s/%s: %s",
-			  spool_dir, input_spool_fn, error);
-	    } else {
-		write_log(LOG_SYS, "open_spool: %s/%s: %s: %s",
-			  spool_dir, input_spool_fn, error, strerror(errno));
+	if (open_spool(spfn, TRUE, LOG_SYS) == FAIL) {
+	    if (exitvalue == EX_TEMPFAIL || exitvalue == EX_NOINPUT) {
+		/* XXX in theory this should be just a DEBUG() */
+		write_log(LOG_TTY|LOG_SYS,
+			  "process_spool_file: %s/%s: file %s",
+			  spool_dir, input_spool_fn,
+			  (exitvalue == EX_TEMPFAIL) ? "already locked; skipping"
+						     : "not found (already processed?)");
 	    }
-	    exit(EX_OSFILE);
+	    exit(exitvalue);
 	}
 	argv = read_message();
 
