@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_100:pathto.c,v 1.10 1997/03/07 03:38:43 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_101:pathto.c,v 1.11 1997/12/16 22:11:57 woods Exp"
  */
 
 /*
@@ -365,7 +365,7 @@ pathto_route(in_addr, error)
     struct addr *defer = NULL;
     struct addr *fail = NULL;
     struct addr *done = NULL;
-    int form;
+    int form =  PARSE_ERROR;
 
     cur->in_addr = in_addr;
     if (disable_smarthost) {
