@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_100:resolve.c,v 1.9 1997/12/08 00:51:43 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_101:resolve.c,v 1.11 1997/12/12 22:16:03 woods Exp"
  */
 
 /*
@@ -84,34 +84,38 @@ resolve_addr_list(in, out, defer, fail, hash_addrs)
     DEBUG(DBG_RESOLVE_HI, "resolve_addr_list called\n");
 
     /*
-     * resolve all addresses in our input queue
-     * each step through the loop advances the progress
+     * Resolve all addresses in our input queue.
+     *
+     * Each step through the loop advances the progress
      * in resolving all addresses to a transport.
+     *
      * The loop is done when nothing remains to be processed.
-     * as an optimization, remote form processing is not
-     * done unless no local processing was required.
+     *
+     * As an optimization, remote form processing is not
+     * done unless/until no local processing was required.
      */
     while (in || remote) {
-
 	/*
-	 * split the input list into local and remote
-	 * forms.
+	 * split the input list into local and remote forms.
 	 */
 	for (cur = in, in = NULL; cur; cur = next) {
-	    int form;			/* form from parse_address */
-
-	    next = cur->succ;
+	    int form;			/* address form from parse_address() */
 
 	    DEBUG1(DBG_RESOLVE_HI, "resolve_addr_list working on %s.\n", cur->work_addr);
+	    next = cur->succ;
+
+	    /* First, if allowed, we try adding the current address to the
+	     * master hash table to ensure we don't do extra work checking
+	     * obviously identical addresses.  Note that since we don't
+	     * re-parse anything that looks anything like a remote address we
+	     * don't protect from multiple deliveries to different addresses
+	     * that really do resolve to the same adress.  We leave final
+	     * duplicate stripping to a final scan of the out list.
+	     */
 	    if (hash_addrs &&
 		!(cur->flags & ADDR_DONTHASH) &&
-		add_to_hash(cur->work_addr, (char *)NULL, 0,
-			    hit_table) == ALREADY_HASHED)
-	    {
-		/*
-		 * we have already seen this address, don't
-		 * process it again
-		 */
+		add_to_hash(cur->work_addr, (char *)NULL, 0, hit_table) == ALREADY_HASHED) {
+		DEBUG1(DBG_RESOLVE_LO, "%s: has already been seen -- skipping.\n", cur->work_addr);
 		continue;
 	    }
 
@@ -148,30 +152,35 @@ resolve_addr_list(in, out, defer, fail, hash_addrs)
 		 */
 		if (strip(cur->remainder)) {
 		    /* it was in quotes, put it back on the input */
+		    DEBUG1(DBG_RESOLVE_HI, "re-parsing quoted local form %s.\n", cur->remainder);
 		    next = cur;
 		} else {
 		    if (!cur->local_name)
 			cur->local_name = visible_name;
 		    cur->succ = local;
 		    local = cur;
+		    DEBUG1(DBG_RESOLVE_HI, "moved local form %s to be directed.\n", cur->remainder);
 		}
 		break;
 
 	    default:			/* anything else is a remote-form address */
-		/* determine if this is actually the local host */
+		/* determine if the target host is actually a local host */
 		if (islocalhost(cur->target)) {
+		    DEBUG1(DBG_RESOLVE_HI, "target %s was actually a local host.\n", cur->target);
 		    /* remember the local name */
-                    cur->local_name = COPY_STRING(cur->target);/* XXX will leak? */
-		    /* it is a local host, so save the name */
+		    cur->local_name = COPY_STRING(cur->target);/* XXX will leak? */
+		    /* it is a local host, but save the name for virtual host processing */
 		    cur->work_addr = COPY_STRING(cur->remainder);/* XXX will leak? */
-		    /* re-parse the current addr */
-		    next = cur;
+		    /* pass the current address to the local directors */
+		    cur->succ = local;
+		    local = cur;
 		    continue;
 		}
 		cur->flags &= ~(ADDR_FORM_MASK);
 		cur->flags |= form;
 		cur->succ = remote;
 		remote = cur;
+		DEBUG1(DBG_RESOLVE_HI, "moved target %s to be routed.\n", cur->target);
 		break;
 	    }
 	}
@@ -187,6 +196,34 @@ resolve_addr_list(in, out, defer, fail, hash_addrs)
 	    remote = NULL;
 	}
     }
+    /* XXX we could probably garbage-collect hit_table at this point */
+    if (hash_addrs) {
+	struct addr *prev;
+	struct hash_table *hit_out_table; /* table to recognize address hits */
+	char *hashval;
+
+	/* XXX - hit_out_table should be associated with a block */
+	hit_out_table = new_hash_table(hit_table_len,
+				       (struct block *) NULL,
+				       HASH_DEFAULT);
+	/*
+	 * Re-scan the out list for duplicates.  Note that a duplicate is
+	 * one that has the same destination *and* the same transport.
+	 */
+	for (cur = *out, prev = NULL; cur; cur = next) {
+	    next = cur->succ;
+	    hashval = xprintf("%s:%s", cur->next_addr, cur->transport->name);
+	    if (add_to_hash(hashval, (char *) NULL, 0, hit_out_table) == ALREADY_HASHED) {
+		DEBUG2(DBG_RESOLVE_LO, "%s via %s: has already been seen -- skipping.\n", cur->next_addr, cur->transport->name);
+		prev->succ = next;
+		cur->succ = NULL;
+		/* XXX should probably garbage collect the duplicate */
+	    } else {
+		prev = cur;
+	    }
+	    xfree(hashval);
+	}
+    }
 }
 
 /*
