@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_100:retry.c,v 1.29 1997/08/24 16:05:55 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_101:retry.c,v 1.30 1997/12/16 22:11:58 woods Exp"
  */
 
 /*
@@ -24,6 +24,21 @@
 #ifdef HAVE_STDLIB_H
 # include <stdlib.h>
 #endif
+#if defined(POSIX_OS)
+# include <unistd.h>
+#else /* not POSIX_OS */
+# if defined (HAVE_UNISTD_H)
+#  include <unistd.h>
+# endif
+#endif	/* not POSIX_OS */
+#if defined(UNIX_SYS5) || defined(POSIX_OS) || defined(USE_FCNTL)
+# include <fcntl.h>
+#else
+# if defined(UNIX_BSD)
+#  include <sys/file.h>
+# endif
+#endif
+
 #include "smail.h"
 #include "addr.h"
 #include "transport.h"
@@ -38,18 +53,6 @@
 # include "error.h"
 #endif
 
-#if defined(UNIX_SYS5) || defined(POSIX_OS) || defined(USE_FCNTL)
-# include <fcntl.h>
-#else
-# if defined(UNIX_BSD)
-#  include <sys/file.h>
-# endif
-#endif
-
-#if defined(POSIX_OS) || defined(UNIX_SYS5)
-# include <unistd.h>			/* for _PC_NAME_MAX (Jim Mercer, FreeBSD 2.0.5) */
-#endif	/* POSIX_OS || UNIX_SYS5 */
-
 #define RETRY_MODE   0644		/* file creation modes */
 
 #ifdef O_SYNC
