@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_100:route.c,v 1.27 1997/12/08 06:07:44 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_101:route.c,v 1.28 1997/12/11 20:48:00 woods Exp"
  */
 
 /*
@@ -512,7 +512,10 @@ route_driver_finish(rp, addr, match_count, next_host, route, transport, hints)
     struct transport *transport;	/* optional transport from driver */
     struct transport_hints *hints;	/* transport hints from driver */
 {
+    DEBUG1(DBG_DRIVER_HI, "route_driver_finish() called for driver %s.\n", rp->driver);
+
     if (addr->flags&ADDR_FINISHED) {
+	DEBUG1(DBG_DRIVER_HI, "%s already finished.\n", addr->in_addr);
 	/*
 	 * a router erroneously found a new route for a finished addr,
 	 * ignore it
@@ -536,18 +539,21 @@ route_driver_finish(rp, addr, match_count, next_host, route, transport, hints)
 	    (addr->target[0] == '.' &&
 	     strlen(addr->target) == match_count - 1))
 	{
+	    DEBUG2(DBG_DRIVER_HI, "%s: full match found to %s.\n", addr->in_addr, addr->target);
+
 	    addr->flags |= ADDR_FINISHED|ADDR_FULLMATCH;
 	} else {
 	    if (next_host == NULL) {
-
 		/*
 		 * the local host cannot be matched partially, so
 		 * ignore any attempts to do so
 		 */
+		DEBUG1(DBG_DRIVER_HI, "%s: partial match found, but next_host is null.\n", addr->in_addr);
 
 		return;
 	    }
 	    if (rp->flags&USE_ALWAYS) {
+		DEBUG1(DBG_DRIVER_HI, "%s: partial match found, but USE_ALWAYS so marking finished.\n", addr->in_addr);
 		addr->flags |= ADDR_FINISHED;
 	    }
 	}
