@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/routers:RELEASE-3_2_0_100:gethost.c,v 1.15 1997/12/08 05:58:40 woods Exp"
+#ident	"@(#)smail/src/routers:RELEASE-3_2_0_101:gethost.c,v 1.16 1997/12/11 20:50:00 woods Exp"
  */
 
 /*
@@ -97,7 +97,10 @@
 #endif
 
 #ifndef INADDR_NONE
-# define INADDR_NONE	((unsigned long)(-1))
+# define INADDR_NONE		((unsigned long) (-1)) /* XXX 64bit too??? */
+#endif
+#ifndef INADDR_LOOPBACK
+# define INADDR_LOOPBACK	((unsigned long) 0x7F000001)
 #endif
 
 /* functions local to this file */
