@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/routers:RELEASE-3_2_0_100:rewrite.c,v 1.8 1997/12/08 00:58:18 woods Exp"
+#ident	"@(#)smail/src/routers:RELEASE-3_2_0_101:rewrite.c,v 1.10 1997/12/11 23:09:38 woods Exp"
  */
 /*
  * rewrite.c
@@ -195,8 +195,14 @@ rtd_rewrite(rp, in, out, defer, fail)
     struct addr **defer;		/* addrs to defer to a later time */
     struct addr **fail;			/* unresolvable addrs */
 {
+    /* 
+     * This router can make changes on a per user basis, or 
+     * have outputs affecting a user.
+     * Hence this flag is set to prevent rtd_standard caching
+     * the routing information from it.
+     */
+    rp->flags |= RT_AFFECTS_USER;
     rtd_standard(rp, in, out, defer, fail, rewrite_lookup);
-
     close_if_reopen(rp);
 }
 
@@ -212,6 +218,13 @@ rtv_rewrite(rp, in, retry, okay, defer, fail)
     struct addr **defer;		/* temporariliy unverifiable addrs */
     struct addr **fail;			/* unverified addrs */
 {
+    /* 
+     * This router can make changes on a per user basis, or 
+     * have outputs affecting a user.
+     * Hence this flag is set to prevent rtd_standard caching
+     * the routing information from it.
+     */
+    rp->flags |= RT_AFFECTS_USER;
     rtv_standard(rp, in, retry, okay, defer, fail, rewrite_lookup);
     close_if_reopen(rp);
 }
@@ -305,30 +318,20 @@ rtb_rewrite(rp, attrs)
     struct rewrite_private *priv;	/* new rewrite_private structure */
 
     /* copy the template private data */
-    priv = (struct rewrite_private *)xmalloc(sizeof(*priv));
-    (void) memcpy((char *)priv, (char *)&rewrite_template, sizeof(*priv));
+    priv = (struct rewrite_private *) xmalloc(sizeof(*priv));
+    (void) memcpy((char *) priv, (char *) &rewrite_template, sizeof(*priv));
+    rp->private = (char *) priv;
 
-    rp->private = (char *)priv;
     /* fill in the attributes of the private data */
-    error = fill_attributes((char *)priv,
-			    attrs,
-			    &rp->flags,
-			    rewrite_attributes,
-			    end_rewrite_attributes);
-
-    /* 
-     * This router can make changes on a per user basis, or 
-     * have outputs affecting a user.
-     * Hence this flag is set to prevent rtd_standard caching
-     * the routing information from it.
-     */
-    rp->flags |= RT_AFFECTS_USER;
-
-    if (error) {
+    if ((error = fill_attributes((char *) priv,
+				 attrs,
+				 &rp->flags,
+				 rewrite_attributes,
+				 end_rewrite_attributes))) {
 	return error;
-    } else {
-	return NULL;
     }
+
+    return NULL;
 }
 
 /*
