@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/routers:RELEASE-3_2_0_100:rtlib.c,v 1.8 1997/03/07 03:23:03 woods Exp"
+#ident	"@(#)smail/src/routers:RELEASE-3_2_0_101:rtlib.c,v 1.10 1997/12/11 23:08:42 woods Exp"
  */
 
 /*
@@ -38,14 +38,17 @@
  * These routines calls a lookup function to route individual target
  * names.  This lookup routine will be called as follows:
  *
- *	success = (*lookup)(rp, addr, fl, &rt_info, &error);
- *	 int success;			- output: success value
- *	 struct router *rp;		- input: router entry
- *	 struct addr *addr;		- input: addr to route
- *	 int fl;			- input: flags affecting operation
- *	 struct rt_info rt_info;	- output: routing information
- *	 struct error *error;		- output: routing error
- *	 int len;			- output: target match length
+ *	result = (*lookup)(rp, addr, fl, &rt_info, &error);
+ *
+ *	    int result;			- output: success value
+ *
+ *	    struct router *rp;		- input: router entry
+ *	    struct addr *addr;		- input: addr to route
+ *	    int fl;			- input: flags affecting operation
+ *
+ *	    struct rt_info rt_info;	- output: routing information
+ *	    struct error *error;	- output: routing error
+ *	    int len;			- output: target match length
  *
  * The lookup routine should route to the target specified in the
  * single stucture passed in 'addr'.  If routing was successful and a
@@ -120,33 +123,37 @@ rtd_standard(rp, in, out, defer, fail, lookup)
     struct addr *next;			/* next addr to process */
     struct error *error = NULL;		/* error from last lookup */
     char *target = NULL;		/* last target that was checked */
-    int success;			/* results of last lookup */
+    int result = DB_NOMATCH;		/* results of last lookup */
 					/* XXX un-initialized! */
-    int file_success = 0;		/* non-zero means router error */
+    int file_result = 0;		/* non-zero means router error */
     struct rt_info rt_info;		/* routing info from router */
 
-    DEBUG1(DBG_DRIVER_HI, "rtd_%s called\n", rp->driver);
+    DEBUG1(DBG_DRIVER_HI, "rtd_standard() called from rtd_%s()\n", rp->driver);
+
     for (cur = in; cur; cur = next) {
 
 	next = cur->succ;
 
 	if (cur->flags&ADDR_FINISHED) {
 	    /* this addr has already been completed, skip it */
+	    DEBUG1(DBG_DRIVER_HI, "%s: already finished routing, moving to out list.\n", cur->in_addr);
 	    cur->succ = *out;
 	    *out = cur;
 	    continue;
 	}
 
-	if (file_success) {
-	    switch (file_success) {
+	if (file_result) {
+	    switch (file_result) {
 
 	    case FILE_NOMATCH:
+		DEBUG1(DBG_DRIVER_HI, "%s: router disabled, moving to out list.\n", cur->in_addr);
 		cur->succ = *out;
 		*out = cur;
 		continue;
 
 	    case FILE_FAIL:
 	    case FILE_AGAIN:
+		DEBUG1(DBG_DRIVER_HI, "%s: router failed, moving to error & defer lists.\n", cur->in_addr);
 		cur->error = error;	/* use error from last lookup */
 		cur->succ = *defer;
 		*defer = cur;
@@ -161,18 +168,21 @@ rtd_standard(rp, in, out, defer, fail, lookup)
 	     * The current target differs from the previous target, so
 	     * look it up.
 	     */
+	    DEBUG1(DBG_DRIVER_HI, "%s: clearing rt_info and preparing to call lookup().\n", cur->in_addr);
 	    rt_info.next_host = NULL;
 	    rt_info.route = NULL;
 	    rt_info.transport = NULL;
-	    rt_info.tphint_list = (struct transport_hints *) 0;
+	    rt_info.tphint_list = (struct transport_hints *) NULL;
 	    error = NULL;
 	    target = cur->target;
 	    /* no flags to pass */
-	    success = (*lookup)(rp, cur, 0, &rt_info, &error);
+	    result = (*lookup)(rp, cur, 0, &rt_info, &error);
+	} else {
+	    DEBUG1(DBG_DRIVER_HI, "%s: same target, re-using result from last lookup().\n", cur->in_addr);
 	}
 
 	/* Finish up routing, based on lookup response code */
-	switch (success) {
+	switch (result) {
 	case DB_SUCCEED:
 	    /* found a successful match */
 	    route_driver_finish(rp, cur, rt_info.matchlen, rt_info.next_host,
@@ -206,7 +216,7 @@ rtd_standard(rp, in, out, defer, fail, lookup)
 	    /* The file was not found, don't match any addresses. */
 	    cur->succ = *out;
 	    *out = cur;
-	    file_success = FILE_NOMATCH;
+	    file_result = FILE_NOMATCH;
 	    break;
 
 	case FILE_FAIL:
@@ -215,7 +225,7 @@ rtd_standard(rp, in, out, defer, fail, lookup)
 	    cur->error = error;
 	    cur->succ = *defer;
 	    *defer = cur;
-	    file_success = FILE_FAIL;
+	    file_result = FILE_FAIL;
 	    break;
 
 	case FILE_AGAIN:
@@ -223,7 +233,7 @@ rtd_standard(rp, in, out, defer, fail, lookup)
 	    cur->error = error;
 	    cur->succ = *defer;
 	    *defer = cur;
-	    file_success = FILE_AGAIN;
+	    file_result = FILE_AGAIN;
 	    break;
 	}
     }
@@ -243,18 +253,19 @@ rtv_standard(rp, in, retry, okay, defer, fail, lookup)
     struct addr *next;			/* next addr to process */
     struct error *error = NULL;		/* error from last lookup */
     char *target = NULL;		/* last target that was checked */
-    int success;			/* results of last lookup */
+    int result = DB_NOMATCH;		/* results of last lookup */
 					/* XXX un-initialized! */
-    int file_success = 0;		/* non-zero means router error */
+    int file_result = 0;		/* non-zero means router error */
     struct rt_info rt_info;		/* routing info from router */
 
-    DEBUG1(DBG_DRIVER_HI, "rtv_%s called\n", rp->driver);
+    DEBUG1(DBG_DRIVER_HI, "rtv_standard() called from rtd_%s()\n", rp->driver);
+
     for (cur = in; cur; cur = next) {
 
 	next = cur->succ;
 
-	if (file_success) {
-	    switch (file_success) {
+	if (file_result) {
+	    switch (file_result) {
 
 	    case FILE_NOMATCH:
 		cur->succ = *retry;
@@ -279,11 +290,11 @@ rtv_standard(rp, in, retry, okay, defer, fail, lookup)
 	     */
 	    error = NULL;
 	    target = cur->target;
-	    success = (*lookup)(rp, cur, RT_VERIFY, &rt_info, &error);
+	    result = (*lookup)(rp, cur, RT_VERIFY, &rt_info, &error);
 	}
 
 	/* Finish up routing, based on lookup response code */
-	switch (success) {
+	switch (result) {
 	case DB_SUCCEED:
 	    /* Found a successful match. */
 	    cur->succ = *okay;
@@ -322,7 +333,7 @@ rtv_standard(rp, in, retry, okay, defer, fail, lookup)
 	    cur->error = error;
 	    cur->succ = *defer;
 	    *defer = cur;
-	    file_success = FILE_FAIL;
+	    file_result = FILE_FAIL;
 	    break;
 
 	case FILE_AGAIN:
@@ -330,7 +341,7 @@ rtv_standard(rp, in, retry, okay, defer, fail, lookup)
 	    cur->error = error;
 	    cur->succ = *defer;
 	    *defer = cur;
-	    file_success = FILE_AGAIN;
+	    file_result = FILE_AGAIN;
 	    break;
 	}
     }
