@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_100:spool.c,v 1.22 1997/10/16 02:52:37 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_101:spool.c,v 1.25 1997/12/16 22:12:01 woods Exp"
  */
 
 /*
@@ -34,6 +34,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <errno.h>
+#include <signal.h>
 #include "defs.h"
 #ifdef HAVE_STDLIB_H
 # include <stdlib.h>
@@ -180,7 +181,7 @@ extern int errno;
 int
 creat_spool()
 {
-    DEBUG(DBG_SPOOL_HI, "create_spool called\n");
+    DEBUG(DBG_SPOOL_HI, "creat_spool called\n");
     funct_name = "creat_spool";
     temp_fn = NULL;
     spool_fn = NULL;
@@ -949,19 +950,26 @@ copy_old_spool()
  * As a side effect, msg_buf will be loaded with the first part of the
  * spool file.
  *
- * return SUCCEED or FAIL.  If fail, load error with error message.
- * errno will be 0 if no system error was involved.
+ * return SUCCEED or FAIL.  If fail, set `exitvalue' with a suggested
+ * exit value.  EX_TEMPFAIL means a temporary failure which might have
+ * occurred due to a race with another smail process (i.e. file already
+ * locked).  EX_NOINPUT the input file didn't exitst (again because we
+ * may have raced with another smail process which processed the file).
+ * Other exitvalue settings represent more serious problems.
+ *
+ * No log message is generated for EX_TEMPFAIL and EX_NOINPUT.
  */
 int
-open_spool(fn, lock, error)
+open_spool(fn, lock, logopts)
     char *fn;				/* basename of spool file */
     int lock;				/* if TRUE, lock the file */
-    char **error;			/* return error message here */
+    int logopts;			/* which log files to write */
 {
     static char lfn[sizeof("lock/") + SPOOL_FN_LEN];
     struct stat statbuf;
 
-    DEBUG1(DBG_SPOOL_HI, "open_spool(%s) called\n", fn);
+    DEBUG3(DBG_SPOOL_HI, "open_spool(%s, %d, 0x%x) called\n",
+	   fn, lock, logopts);
     funct_name = "open_spool";
     message_id = NULL;
     lock_fn = NULL;
@@ -977,8 +985,8 @@ open_spool(fn, lock, error)
     msg_max = msg_buf;			/* start at beginning of buffer */
     end_msg_buf = msg_buf + message_bufsiz;
     if (fn[0] != '/') {
-	DEBUG1(DBG_SPOOL_LO, "open_spool: %s: relative pathname!\n", fn);
-	*error = "filename not absolute";
+	write_log(logopts, "open_spool: %s: filename not absolute", fn);
+	exitvalue = EX_SOFTWARE;
 	return FAIL;
     }
     spool_dir = fn;		/* get directory from fn */
@@ -988,22 +996,24 @@ open_spool(fn, lock, error)
     if (input_spool_fn < spool_dir ||
 	strncmp(input_spool_fn, "/input", sizeof("/input") - 1))
     {
-	DEBUG1(DBG_SPOOL_LO, "open_spool failed: %s: invalid spool filename",
-	       spool_dir);
-	*error = "invalid spool filename";
+	write_log(logopts, "open_spool failed: %s: invalid spool filename",
+		  spool_dir);
+	exitvalue = EX_SOFTWARE;
 	return FAIL;
     }
     *input_spool_fn++ = '\0';
 
     if (chdir(spool_dir) < 0) {
-	DEBUG2(DBG_SPOOL_LO, "open_spool failed: %s: chdir failed: %s",
-	       spool_dir, strerror(errno));
-	*error = "chdir failed";
+	write_log(logopts, "open_spool failed: chdir(%s): %s",
+		  spool_dir, strerror(errno));
+	exitvalue = EX_OSFILE;
 	return FAIL;
     }
 
     /*
-     * attempt to open the file
+     * attempt to open the file.  if the open fails because the file
+     * is missing, it is likely that we raced another smail process
+     * for the file.
      *
      * some of the OS locking algorithms require that the file be
      * opened for writing.  For such systems, the spool_mode must have
@@ -1018,9 +1028,12 @@ open_spool(fn, lock, error)
 	spoolfile = open(input_spool_fn, O_RDONLY);
     }
     if (spoolfile < 0) {
-	DEBUG3(DBG_SPOOL_LO, "open_spool: %s/%s: open failed: %s\n",
-	       spool_dir, input_spool_fn, strerror(errno));
-	*error = "open failed";
+	exitvalue = EX_NOINPUT;
+	if (errno != ENOENT) {	
+	    exitvalue = EX_NOPERM;
+	    write_log(logopts, "open_spool: %s/%s: open failed: %s\n",
+		      spool_dir, input_spool_fn, strerror(errno));
+	}
 	return FAIL;
     }
 
@@ -1030,10 +1043,10 @@ open_spool(fn, lock, error)
 	(void) sprintf(lfn, "lock/%s", spool_fn);
 	lock_fn = lfn;
 	if (lock_spoolfile(l_open) == FAIL) {
-	    DEBUG2(DBG_SPOOL_MID, "open_spool: %s/%s: lock_by_name failed\n",
+	    DEBUG2(DBG_SPOOL_LO, "open_spool: %s/%s: lock_spoolfile failed\n",
 		   spool_dir, input_spool_fn);
 	    (void) close(spoolfile);
-	    *error = "lock_spoolfile() failed";
+	    exitvalue = EX_TEMPFAIL;
 	    return FAIL;
 	}
 #else /* lock_fd */
@@ -1041,18 +1054,18 @@ open_spool(fn, lock, error)
 	    (void) sprintf(lfn, "lock/%s", spool_fn);
 	    lock_fn = lfn;
 	    if (lock_spoolfile(l_open) == FAIL) {
-		DEBUG2(DBG_SPOOL_MID, "open_spool: %s/%s: lock_spoolfile failed\n",
+		DEBUG2(DBG_SPOOL_LO, "open_spool: %s/%s: lock_by_name failed\n",
 		       spool_dir, input_spool_fn);
 		(void) close(spoolfile);
-		*error = "lock_spoolfile() failed";
+		exitvalue = EX_TEMPFAIL;
 		return FAIL;
 	    }
 	} else {
 	    if (lock_fd(spoolfile) == FAIL) {
-		DEBUG2(DBG_SPOOL_MID, "open_spool: %s/%s: lock failed\n",
+		DEBUG2(DBG_SPOOL_LO, "open_spool: %s/%s: lock failed\n",
 		       spool_dir, input_spool_fn);
 		(void) close(spoolfile);
-		*error = "lock_fd() failed";
+		exitvalue = EX_TEMPFAIL;
 		return FAIL;
 	    }
 	}
@@ -1062,16 +1075,18 @@ open_spool(fn, lock, error)
     /*
      * Get statistics on spool file.
      */
-    (void) fstat(spoolfile, &statbuf);
-
-    /*
-     * If the file has been removed, then don't process it.
-     */
-    if (statbuf.st_nlink == 0) {
-	DEBUG2(DBG_SPOOL_MID,
-	       "open_spool: %s/%s: spool file was removed\n",
+    if (fstat(spoolfile, &statbuf) < 0) {
+	if (errno != ENOENT) {
+	    write_log(logopts, "open_spool: %s/%s: spool file fstat() error: %s\n",
+		      spool_dir, input_spool_fn, strerror(errno));
+	    close_spool();
+	    exitvalue = EX_SOFTWARE;
+	    return FAIL;
+	}
+	DEBUG2(DBG_SPOOL_MID, "open_spool: %s/%s: spool file was removed\n",
 	       spool_dir, input_spool_fn);
 	close_spool();
+	exitvalue = EX_NOINPUT;
 	return FAIL;
     }
 
@@ -1088,7 +1103,6 @@ open_spool(fn, lock, error)
     }
     msg_max = msg_buf;
     msg_ptr = msg_buf;
-    (void) fstat(spoolfile, &statbuf);
     msg_size = statbuf.st_size;
 
     if (lock) {
@@ -1170,12 +1184,13 @@ defer_message()
     }
     if (success < 0) {
 	write_log(LOG_PANIC|LOG_SYS,
-		  "defer_message: error linking %s/%s to error/%s: %s",
-		  spool_dir, save_input_spool_fn, spool_fn, strerror(errno));
+		  "defer_message: error linking %s/%s to %s/%s: %s",
+		  spool_dir, save_input_spool_fn, spool_dir, error_fn,
+		  strerror(errno));
     } else {
 	if (errfile) {
-	    write_log(LOG_TTY|LOG_SYS, "mail moved to %s/error/%s",
-		      spool_dir, save_spool_fn);
+	    write_log(LOG_TTY|LOG_SYS, "mail moved to %s/%s",
+		      spool_dir, error_fn);
 	}
 	input_spool_fn = save_input_spool_fn;
 	spool_fn = save_spool_fn;
@@ -1478,6 +1493,8 @@ set_alt_spool(m)
     static char *altlist = NULL;
     char *p;
 
+    DEBUG1(DBG_SPOOL_HI, "set_alt_spool called\n", m);
+
     /* log the message using the old spool dir then set the new one */
     if (m) {
 	log_message(m);
@@ -1714,24 +1731,28 @@ spool_max_free_space ()
 #ifdef STANDALONE
 
 char *program = "spool";
-char *spool_dirs = "/usr/spool/smail:/wd1h/spool/smail:/usr/tmp/spool/smail";
+FILE *errfile = stderr;
+int return_to_sender = FALSE;
 int debug = 0;
-int message_bufsiz = MESSAGE_BUF_SIZE;
-int spool_mode = 0444;
-int spool_grade = 'C';
-int lock_mode = 0444;
+int exitvalue = 0;
 
 /*
  * standalone main for spooling subsystem.
  * usage:
- *	spool [-ddebug] [-msize] o|c[w][u] [filename]
+ *	spool [-ddebug] [-msize] [-sspool_dirs] [-n] o|c[w][u] [filename]
  *
- * -d sets the debug level, -m sets message_bufsiz.  An arg of `o'
- * causes a spool file in the given filename to be locked, written to
- * standard out and closed.  An arg of `c' causes a spool file to be
- * read from standard input and put in a new spool file.  If `w'
- * follows `o' or `c' then write the spool file to standard out before
- * closing.  If `u' then unspool the message.
+ * -d sets the debug level, -m sets message_bufsiz, -s sets the spool
+ * directory(s), and -n causes the lock_by_name code to be used.
+ *
+ * An arg of `o' causes a spool file in the given filename to be locked,
+ * written to standard out and closed.  An arg of `c' causes a spool
+ * file to be read from standard input and put in a new spool file.  If
+ * `w' follows `o' or `c' then write the spool file to standard out
+ * before closing.  If `u' then unspool the message.
+ *
+ * If an arg of `c' is used and stdin contains a `@' character than
+ * a write error is simulated to exercise the alternate spooling
+ * directory code.
  */
 void
 main(argc, argv)
@@ -1746,7 +1767,7 @@ main(argc, argv)
     program = *argv++;
     --argc;
 
-    while ((*argv)[0] == '-') {
+    while (*argv && (*argv)[0] == '-') {
 	switch ((*argv)[1]) {
 	case 'd':
 	    debug = atoi(*argv + 2);
@@ -1754,6 +1775,12 @@ main(argc, argv)
 	case 'm':
 	    message_bufsiz = atoi(*argv + 2);
 	    break;
+	case 's':
+	    spool_dirs = *argv + 2;
+	    break;
+	case 'n':
+	    lock_by_name = 1;
+	    break;
 	default:
 	    stand_spool_usage();
 	    /*NOTREACHED*/
@@ -1802,15 +1829,17 @@ main(argc, argv)
 	exit(EX_USAGE);
     }
     if (mode == 'o') {
-	if (open_spool(*argv) < 0) {
+	if (open_spool(*argv, TRUE, 0) < 0) {
 	    (void) fprintf(stderr, "%s: open failed\n", program);
-	    exit(EX_OSFILE);
+	    log_spool_errors();
+	    exit(exitvalue);
 	}
     } else {
 	register int c;
 
 	if (creat_spool(*argv) < 0) {
 	    (void) fprintf(stderr, "%s: creat failed\n", program);
+	    log_spool_errors();
 	    exit(EX_OSFILE);
 	}
 	while ((c = getchar()) != EOF) {
@@ -1819,6 +1848,7 @@ main(argc, argv)
 	    }
 	    if (PUTSPOOL(c) == FAIL) {
 		(void) fprintf(stderr, "%s: write failed\n", program);
+		log_spool_errors();
 		exit(EX_IOERR);
 	    }
 	}
@@ -1846,7 +1876,8 @@ main(argc, argv)
 
 stand_spool_usage()
 {
-    (void) fprintf(stderr, "usage: %s [-ddebug] [-msize] o|c[w][u] [file]\n",
+    (void) fprintf(stderr,
+	 "usage: %s [-ddebug] [-msize] [-sspool_dirs] [-n] o|c[w][u] [file]\n",
 		   program);
     exit(EX_USAGE);
 }
