@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_100:string.c,v 1.22 1996/11/26 21:01:01 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_101:string.c,v 1.23 1997/12/16 22:12:03 woods Exp"
  */
 
 /*
@@ -24,6 +24,9 @@
 #include <stdio.h>
 #include <ctype.h>
 #include "defs.h"
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
 #ifndef STANDALONE
 # include <varargs.h>
 # include "smail.h"
