@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_100:sysdep.c,v 1.66 1997/12/01 23:57:10 woods Exp
+#ident	"@(#)smail/src:RELEASE-3_2_0_101:sysdep.c,v 1.67 1997/12/16 22:22:20 woods Exp
  */
 
 /*
@@ -53,6 +53,9 @@
 # endif
 #endif
 
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
 #if defined(POSIX_OS)
 # include <limits.h>
 # include <unistd.h>
@@ -90,7 +93,7 @@
 # include <sys/time.h>
 #endif
 
-#if defined(POSIX_OS) || defined(INCLUDE_UTIME_H)
+#if defined(POSIX_OS) || defined(HAVE_UTIME_H)
 # include <utime.h>
 #else
 # if defined(DECLARE_UTIMBUF) && !defined(NO_DECLARE_UTIMBUF)
@@ -99,7 +102,7 @@
 	time_t modtime;
     };
 # endif	/* DECLARE_UTIMBUF */
-#endif	/* POSIX_OS || INCLUDE_UTIME_H */
+#endif	/* POSIX_OS || HAVE_UTIME_H */
 
 #if !defined(UNIX_BSD) && !defined(UNIX_SYS5) && !defined(POSIX_OS)
 /* use this for ancient ftime() system call, as a last resort */
