@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_100:transport.c,v 1.29 1996/11/26 21:01:47 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_101:transport.c,v 1.30 1997/12/16 22:12:05 woods Exp"
  */
 
 /*
@@ -29,6 +29,14 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include "defs.h"
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+#if (defined(POSIX_OS) || !defined(UNIX_BSD)) && !defined(ISC_SOCKET_TIME_BUG)
+# include <time.h>
+#else
+# include <sys/time.h>
+#endif
 #include "smail.h"
 #include "addr.h"
 #include "transport.h"
@@ -53,6 +61,9 @@
 /* variables imported from libc */
 extern int errno;
 
+/* functions imported from libc */
+extern time_t time();
+
 /* variables exported from this file */
 char *path_to_sender = NULL;		/* uucp-style route to sender */
 int cached_transports = FALSE;		/* TRUE if cache_transports() called */
@@ -340,7 +351,7 @@ call_transports(asn, defer, fail)
 	}
 
 	/* determine official time of attempt */
-	time(&started);
+	(void) time(&started);
 
 	/* call the transport */
 	succeed = NULL;
