@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/transports:RELEASE-3_2_0_100:tcpsmtp.c,v 1.33 1997/08/30 20:57:55 woods Exp"
+#ident	"@(#)smail/src/transports:RELEASE-3_2_0_101:tcpsmtp.c,v 1.34 1997/12/16 22:08:52 woods Exp"
  */
 
 /*
@@ -51,6 +51,9 @@
 /* variables imported from libc */
 extern int errno;
 
+/* functions imported from libc */
+extern time_t time();
+
 /* functions local to this file */
 #ifdef HAVE_BIND
 static int tcpsmtp_bind();
@@ -145,7 +148,7 @@ tpd_tcpsmtp(addr, succeed, defer, fail)
                     retry_host_lock(addr->transport, ip_addr->hostname,
                                     &defer_failure, &error) == SUCCEED)
                 {
-                    time(&started);
+                    (void) time(&started);
                     error = NULL;
                     ret = tcpsmtp_internal(addr, succeed, defer, fail,
                                            ip_addr->hostname, &ip_addr->addr,
@@ -328,9 +331,9 @@ tcpsmtp_internal(addr,succeed,defer,fail,hostname,ipaddr,family,service,ep)
 {
     struct transport *tp = addr->transport;
     struct tcpsmtp_private *priv;
-    int s;                              /* socket */
-    int s2;                             /* dup of s */
-    struct smtp smtpbuf;                /* SMTP description buffer */
+    int s = -1;				/* socket */
+    int s2 = -1;			/* dup of s */
+    struct smtp smtpbuf;		/* SMTP description buffer */
     char *error_text;
     int success;
     struct addr *ap;
