@@ -1,4 +1,4 @@
-/* @(#) dcasehost.c,v 1.4 1992/09/06 01:10:10 tron Exp */
+/* @(#) dcasehost.c,v 1.5 1997/12/16 22:07:28 woods Exp */
 
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
@@ -26,6 +26,9 @@
 #include <stdio.h>
 #include <ctype.h>
 #include "defs.h"
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
 
 char *program;			/* argv[0] from main */
 
@@ -33,7 +36,7 @@ char buf[BUFSIZ+1+1];		/* i/o line buffer */
 char buf2[BUFSIZ+1+1];		/* holder for field one switch (-c) */
 char buf3[BUFSIZ+1+1];		/* holder for other fields (-c) */
 
-void
+int
 main(argc, argv)
     int argc;		/* arg count */
     char *argv[];	/* args */
@@ -131,4 +134,6 @@ main(argc, argv)
 	fputs(buf, stdout);
     }
     exit(0);
+
+    /* NOTREACHED */
 }
