@@ -1,4 +1,4 @@
-/* @(#) gleem.c,v 1.4 1992/07/11 11:39:57 tron Exp */
+/* @(#) gleem.c,v 1.5 1997/12/16 22:07:30 woods Exp */
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
  *    Copyright (C) 1992  Ronald S. Karr
@@ -56,6 +56,9 @@
 
 #include <stdio.h>
 #include "defs.h"
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
 
 #define BUFFER_SIZE 4096		/* length of longest line */
 
@@ -68,6 +71,7 @@ void file_2_space();			/* convert file {...} to spaces */
 char *program;				/* our name */
 int errors = 0;				/* 1 ==> errors were encountered */
 
+int
 main(argc, argv)
     int argc;				/* arg count */
     char *argv[];			/* args */
@@ -167,6 +171,8 @@ main(argc, argv)
      * exit noting if errors happened
      */
     exit(errors);
+
+    /* NOTREACHED */
 }
 
 /*
