@@ -1,4 +1,4 @@
-/* @(#) mkdbm.c,v 1.10 1997/05/05 16:37:00 woods Exp */
+/* @(#) mkdbm.c,v 1.13 1997/12/17 19:33:44 woods Exp */
 
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
@@ -21,6 +21,25 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include "defs.h"
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+#if defined(POSIX_OS)
+# include <limits.h>
+# include <unistd.h>
+#else /* not POSIX_OS */
+# if defined (HAVE_LIMITS_H)
+#  include <limits.h>
+# endif
+# if defined (HAVE_UNISTD_H)
+#  include <unistd.h>
+# endif
+#endif	/* not POSIX_OS */
+#if (defined(POSIX_OS) || !defined(UNIX_BSD)) && !defined(ISC_SOCKET_TIME_BUG)
+# include <time.h>
+#else
+# include <sys/time.h>
+#endif
 #include "smail.h"
 #include "dys.h"
 #include "exitcodes.h"
@@ -40,7 +59,9 @@
 #include <sys/utsname.h>
 #endif
 
+/* variables provided by this file */
 char *program;				/* argv[0] from main */
+
 /* variables local to this file */
 static char *out_name = NULL;
 static char *temp_dir = NULL;
@@ -62,9 +83,22 @@ static void add_to_database();
 static void add_ending_record();
 static char *getline();
 static void rename_database();
+static void add_yp_stamps();
+
+/* functions provided by this file */
+extern char *xmalloc();
+extern char *xrealloc();
+
+/* functions imported from libc */
+#if !defined(HAVE_STDLIB_H) && !defined(HAVE_MALLOC_H)
+extern char *malloc();
+extern char *realloc();
+extern void free();				/* int on SunOS */
+#endif
+extern time_t time();
 
 /*ARGSUSED*/
-void
+int
 main(argc, argv)
     int argc;
     char **argv;
@@ -127,8 +161,11 @@ main(argc, argv)
 
     dbmclose();
     exit(EX_OK);
+
+    /* NOTREACHED */
 }
 
+static void
 add_yp_stamps()
 {
 	datum key_lastmod, val_lastmod;
@@ -213,7 +250,7 @@ static void
 done(ex)
     int ex;
 {
-    dbmclose();
+    (void) dbmclose();
     (void) unlink(temp_dir);
     (void) unlink(temp_pag);
     exit(ex);
@@ -311,7 +348,9 @@ static void
 create_database(dbm_name)
     char *dbm_name;
 {
+#ifndef DBM_SUFFIX	/* db emulation of ndbm */
     int fd;
+#endif
     int temp_len = strlen(dbm_name);
 
 #ifdef DBM_SUFFIX	/* db emulation of ndbm */
@@ -362,7 +401,7 @@ add_to_database(f)
 {
     register char *s;
 
-    while (s = getline(f)) {
+    while ((s = getline(f))) {
 	register char *data;
 	datum key, content;
 
@@ -460,9 +499,11 @@ rename_database(from, to)
     unsigned int fromlen = (unsigned)strlen(from);
     unsigned int tolen = (unsigned)strlen(to);
     char *from_dir = xmalloc(fromlen + sizeof(".dir"));
-    char *from_pag = xmalloc(fromlen + sizeof(".pag"));
     char *to_dir = xmalloc(tolen + sizeof(".dir"));
+#ifndef DBM_SUFFIX
     char *to_pag = xmalloc(tolen + sizeof(".pag"));
+    char *from_pag = xmalloc(fromlen + sizeof(".pag"));
+#endif
 
 #ifdef DBM_SUFFIX
     (void) sprintf(from_dir, "%s%s", from, DBM_SUFFIX);
@@ -501,7 +542,6 @@ char *
 xmalloc(len)
     unsigned int len;
 {
-    char *malloc();
     register char *ret = malloc(len);
 
     if (ret == NULL) {
@@ -516,7 +556,6 @@ xrealloc(s, len)
     char *s;
     unsigned int len;
 {
-    char *realloc();
     register char *ret = realloc(s, len);
 
     if (ret == NULL) {
