@@ -1,4 +1,4 @@
-/* @(#) mkline.c,v 1.4 1997/01/18 20:43:05 woods Exp */
+/* @(#) mkline.c,v 1.5 1997/12/16 22:07:34 woods Exp */
 
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
@@ -18,6 +18,9 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include "defs.h"
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
 #include "smail.h"
 #include "extern.h"
 #include "field.h"
@@ -25,17 +28,37 @@
 #include "dys.h"
 #include "exitcodes.h"
 
+/* variables provided by this file */
 char *program;				/* argv[0] from main */
 int debug = 0;
 FILE *errfile;
 int use_tabs_p = FALSE;
 int ignore_keys_p = FALSE;
 
+/* functions provided by this file */
+extern char *xmalloc();
+extern char *xrealloc();
+extern void xfree();
+extern char *qualify_domain();
+extern struct addr *alloc_addr();
+extern char *preparse_address();
+
+/* functions local to this file */
+static int mkaliasline();
+static int mklistline();
+
+/* functions imported by this file */
+#if !defined(HAVE_STDLIB_H) && !defined(HAVE_MALLOC_H)
+extern char *malloc();
+extern char *realloc();
+extern void free();				/* int on SunOS */
+#endif
+
 /*ARGSUSED*/
-void
+int
 main(argc, argv)
     int argc;
-    char **argv;
+    char *argv[];
 {
     int list_files_p = FALSE;		/* TRUE for -l option */
 
@@ -94,8 +117,11 @@ main(argc, argv)
     }
 
     exit(0);
+
+    /* NOTREACHED */
 }
 
+static int
 mkaliasline(f)
     FILE *f;
 {
@@ -151,6 +177,7 @@ mkaliasline(f)
     return 0;
 }
 
+static int
 mklistline(f)
     register FILE *f;
 {
@@ -185,7 +212,6 @@ char *
 xmalloc(len)
     int len;
 {
-    char *malloc();
     register char *ret = malloc(len);
 
     if (ret == NULL) {
@@ -199,7 +225,6 @@ xrealloc(s, len)
     char *s;
     int len;
 {
-    char *realloc();
     register char *ret = realloc(s, len);
 
     if (ret == NULL) {
