@@ -1,4 +1,4 @@
-/* @(#) mksort.c,v 1.6 1997/01/18 20:43:09 woods Exp */
+/* @(#) mksort.c,v 1.7 1997/12/16 22:07:38 woods Exp */
 
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
@@ -18,6 +18,9 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include "defs.h"
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
 #include "smail.h"
 #include "extern.h"
 #include "field.h"
@@ -25,16 +28,30 @@
 #include "dys.h"
 #include "exitcodes.h"
 
+/* variables provided by this file */
 char *program;				/* argv[0] from main */
 int debug = 0;
 FILE *errfile;
 
+/* functions local to this file */
 static int cmp(), cmpic();
 static char **mkvectors();
 static int read_lines();
 
+/* functions provided by this file */
+extern char *xmalloc();
+extern char *xrealloc();
+extern void xfree();
+
+/* functions imported by this file */
+#if !defined(HAVE_STDLIB_H) && !defined(HAVE_MALLOC_H)
+extern char *malloc();
+extern char *realloc();
+extern void free();				/* int on SunOS */
+#endif
+
 /*ARGSUSED*/
-void
+int
 main(argc, argv)
     int argc;
     char **argv;
@@ -84,6 +101,8 @@ main(argc, argv)
     }
 
     exit(0);
+
+    /* NOTREACHED */
 }
 
 static int
@@ -177,7 +196,6 @@ char *
 xmalloc(len)
     int len;
 {
-    char *malloc();
     register char *ret = malloc(len);
 
     if (ret == NULL) {
@@ -191,7 +209,6 @@ xrealloc(s, len)
     char *s;
     int len;
 {
-    char *realloc();
     register char *ret = realloc(s, len);
 
     if (ret == NULL) {
