@@ -1,4 +1,4 @@
-/* @(#) unsharmap.c,v 1.10 1997/02/25 14:17:57 woods Exp */
+/* @(#) unsharmap.c,v 1.11 1997/12/16 22:07:42 woods Exp */
 /*
  *    Copyright (C) 1988 Ronald S. Karr and Landon Curt Noll
  *    Copyright (C) 1992 Ronald S. Karr
@@ -63,6 +63,27 @@
  */
  
 #include <stdio.h>
+#include "defs.h"
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+#if defined(POSIX_OS)
+# include <limits.h>
+# include <unistd.h>
+#else /* not POSIX_OS */
+# if defined (HAVE_LIMITS_H)
+#  include <limits.h>
+# endif
+# if defined (HAVE_UNISTD_H)
+#  include <unistd.h>
+# endif
+#endif	/* not POSIX_OS */
+#ifdef HAVE_STRING_H
+# include <string.h>
+#endif
+#ifndef DEPEND
+# include "extern.h"
+#endif
 
 #define HEADER_OK 1			/* the article header is correct */
 #define HEADER_ERROR 2			/* bad header, skip and log */
@@ -88,9 +109,18 @@ char *check_newline();			/* check to be sure we read a '\n' */
 
 char *xmalloc();			/* for string.c and strcolon()*/
 char *xrealloc();			/* for string.c and strcolon() */
+void xfree();
 
+/* functions imported by this file */
+#if !defined(HAVE_STDLIB_H) && !defined(HAVE_MALLOC_H)
+extern char *malloc();
+extern char *realloc();
+extern void free();				/* int on SunOS */
+#endif
+extern int creat();
 extern char *strcolon();		/* grap strcolon() from src/string.c */
 
+int
 main( argc, argv )
     int argc;				/* arg count */
     char *argv[];			/* args */
@@ -244,6 +274,8 @@ main( argc, argv )
     sprintf(err, "exiting: status: %d -  %s", (errors>0) ? 4 : 0, get_date());
     logit(err);
     exit( (errors>0) ? 4 : 0 );
+
+    /* NOTERACHED */
 }
 
 
@@ -494,7 +526,7 @@ check_preamble( article )
     FILE *article;			/* the article stream */
 {
     char *p;				/* pointer */
-    char *q;				/* pointer, NULL byte of mapname */
+    char *q = NULL;			/* pointer, NULL byte of mapname */
     int bad_echo=0;			/* 1 ==> a bad echo was found */
 
     /*
@@ -625,7 +657,7 @@ write_map( article )
 {
     int fd;				/* map file descriptor */
     FILE *map;				/* the map file stream */
-    char *mappath;
+    char *mappath = mapname;
 
     /*
      * open and truncate the map file
@@ -634,12 +666,11 @@ write_map( article )
 	mappath = xmalloc(strlen(mapdir) + strlen(mapname) + 2);
 	sprintf(mappath, "%s/%s", mapdir, mapname);
 	fd = creat(mappath, 0644);
-	free(mappath);
     } else {
-	fd = creat(mapname, 0644);
+	fd = creat(mappath, 0644);
     }
     if (fd < 0) {
-	sprintf(err, "error: unable to creat/truncate %s\n", mapname);
+	sprintf(err, "error: unable to creat/truncate %s\n", mappath);
 	logit(err);
 	return(1);
     }
@@ -786,7 +817,6 @@ char *
 xmalloc(size)
     unsigned size;
 {
-    extern char *malloc();
     char *ret = malloc(size);
 
     if (ret == NULL) {
@@ -805,7 +835,6 @@ xrealloc(region, size)
     char *region;
     unsigned size;
 {
-    extern char *realloc();
     register char *ret = realloc(region, size);
 
     if (ret == NULL) {
